@@ -1,3 +1,3 @@
-import kplot.lib
+from kplot.lib import *
 
 kplot.lib.loadtheme("colorblind")
